pub struct ExtensionValidationContext { /* private fields */ }Expand description
Narrow validation permissions granted by an extension.
Implementations
Sourceimpl ExtensionValidationContext
impl ExtensionValidationContext
Sourcepub fn allow_accessor_without_buffer_view(&mut self, index: usize)
pub fn allow_accessor_without_buffer_view(&mut self, index: usize)
Allows a registered extension to omit a buffer view for one accessor.
Sourcepub fn allows_accessor_without_buffer_view(&self, index: usize) -> bool
pub fn allows_accessor_without_buffer_view(&self, index: usize) -> bool
Returns whether an accessor has received that narrow exemption.